The source repository for this project can be found at:

  https://opendev.org/openstack/blazar

Pull requests submitted through GitHub are not monitored.

To start contributing to OpenStack, follow the steps in the contribution guide
to set up and use Gerrit:

   https://docs.openstack.org/contributors/code-and-documentation/quick-start.html

Bugs should be filed on Launchpad:

    https://bugs.launchpad.net/blazar

For more specific information about contributing to this repository, see the
blazar contributor guide:

    https://docs.openstack.org/blazar/latest/contributor/contribution.html
